
      program reset_netCDF_attribute

      implicit none

      include 'netcdf.inc'

c     Variables:
      integer narg,varsize,attrsize,filesize,stringsize,nc_status,
     >        type,length
      integer nc_id,var_id
      character*2 attrtype
      character*30 varname,attrname,name
      character*120 filename

c     Variables/values:
      character*512 string_val
      integer*2     i2_val
      integer       i4_val
      real          r4_val
      real*8        r8_val

c     Functions:
      integer str_len,iargc

      narg = iargc()
      if (narg .ne. 5) go to 999

      call getarg(1,filename)
      call getarg(2,varname)
      call getarg(3,attrname)
      call getarg(4,attrtype)
      string_val = ''
      call getarg(5,string_val)
      if      (attrtype .eq. 'i2') then
         read   (string_val,*)i2_val
      else if (attrtype .eq. 'i4') then
         read   (string_val,*)i4_val
      else if (attrtype .eq. 'r4') then
         read   (string_val,*)r4_val
      else if (attrtype .eq. 'r8') then
         read   (string_val,*)r8_val
      else if (attrtype(1:1) .eq. 's') then
         stringsize = str_len(string_val)
      else
         go to 999
      end if

      filesize = str_len(filename)
      varsize  = str_len(varname)
      attrsize = str_len(attrname)

c     Open netCDF file:
      nc_status = NF_OPEN(filename(1:filesize), NF_WRITE, nc_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,1)

c     Get variable ID:
      if (varname(1:varsize) .eq. 'global') then
         var_id = NF_GLOBAL
      else
         nc_status = NF_INQ_VARID(nc_id, varname(1:varsize), var_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,11)
      end if

c     Attribute inquery:
      nc_status = NF_INQ_ATT(nc_id, var_id, attrname(1:attrsize), 
     >                       type, length)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,21)

c     Enter define mode?
      if (attrtype(1:1) .eq. 's' .and. stringsize .gt. length) then
         nc_status = NF_REDEF(nc_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,31)
      else if (attrtype(1:1) .ne. 's' .and. length .gt. 1) then
         go to 998
      end if

c     Check type, reset:

      if (attrtype .eq. 'i2') then
         if (type .ne. NF_SHORT) go to 997
         nc_status = NF_PUT_ATT_INT2(nc_id, var_id,
     >                               attrname(1:attrsize), type,
     >                               1, i2_val)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,41)

      else if (attrtype .eq. 'i4') then
         if (type .ne. NF_INT) go to 997
         nc_status = NF_PUT_ATT_INT(nc_id, var_id,
     >                              attrname(1:attrsize), type,
     >                              1, i4_val)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,42)

      else if (attrtype .eq. 'r4') then
         if (type .ne. NF_REAL) go to 997
         nc_status = NF_PUT_ATT_REAL(nc_id, var_id,
     >                               attrname(1:attrsize), type,
     >                               1, r4_val)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,43)

      else if (attrtype .eq. 'r8') then
         if (type .ne. NF_DOUBLE) go to 997
         nc_status = NF_PUT_ATT_DOUBLE(nc_id, var_id,
     >                                 attrname(1:attrsize), type,
     >                                 1, r8_val)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,44)

      else
         if (type .ne. NF_CHAR) go to 997
         nc_status = NF_PUT_ATT_TEXT(nc_id, var_id,
     >                               attrname(1:attrsize),
     >                               stringsize, string_val)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,45)

      end if


      if (attrtype(1:1) .eq. 's' .and. stringsize .gt. length) then
c        Leave define mode:
         nc_status = NF_ENDDEF(nc_id)
         if (nc_status .ne. NF_NOERR) call handle_err(nc_status,51)
      end if

c     Close file:
      nc_status = NF_CLOSE(nc_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,91)


      go to 1000

 997  write(*,*)
      write(*,*)'Error in the program "reset_netCDF_attribute".'
      write(*,*)' The specified attribute: ',attrname(1:attrsize)
      if (attrtype(1:1) .eq. 's') then
         write(*,*)'  is not of the specified type: ',attrtype(1:1)
      else
         write(*,*)'  is not of the specified type: ',attrtype(1:2)
      end if
      write(*,*)
      write(*,*)'Terminates.'
      write(*,*)
      go to 1000

 998  write(*,*)
      write(*,*)'Error in the program "reset_netCDF_attribute".'
      write(*,*)' The specified attribute: ',attrname(1:attrsize)
      write(*,*)'  is an integer or floating point vector.'
      write(*,*)' The present version of "reset_netCDF_attribute"'
      write(*,*)'  cannot modify a vector.'
      write(*,*)
      write(*,*)'Terminates.'
      write(*,*)
      go to 1000

 999  write(*,*)
      write(*,*)'Error in the program "reset_netCDF_attribute".'
      write(*,*)' SYNTAX ERROR.'
      write(*,*)'  Syntax:'
      write(*,*)' nc_reset_attr <file> <var name> <attr name> <type> ',
     >          '<new value>'
      write(*,*)'  where'
      write(*,*)'   <file>      is the name of a netCDF file'
      write(*,*)'   <var name>  is the name of a variable on <file>;'
      write(*,*)'                for a global attribute, use "global"'
      write(*,*)'   <attr name> is the name of an attribute ',
     >          'of <var name> on <file>'
      write(*,*)'   <type>  is the variable type of <attr name>;'
      write(*,*)'            s  - string'
      write(*,*)'            i2 - integer,        2 bytes'
      write(*,*)'            i4 - integer,        2 bytes'
      write(*,*)'            r4 - floating point, 4 bytes'
      write(*,*)'            r8 - floating point, 8 bytes'
      write(*,*)'   <new value> is the new value of <attr name>'
      write(*,*)
      write(*,*)'Terminates.'
      write(*,*)

 1000 end
