#!/bin/sh

echo ""
echo "    nc_reset_value.sh  Version 1.0"
echo "        Written by Arne Melsom"
echo "           a.melsom@dnmi.no"
echo "            (+47) 2296 3316"
echo "           December 21, 2001"
echo ""


# Check syntax:
###############

if [ "$6" = "" ]
then
    echo ">>>   SYNTAX ERROR   <<<"
    echo ""
    echo ">>> nc_reset_value will reset a value or a range of values to"
    echo ">>>                   a new value, for one variable on a netCDF file"
    echo ">>>                   The climatology consists of fields for"
    echo ""
    echo ">>> Format:"
    echo ">>>  nc_reset_value.sh /file/ /variable/ /type/ /old value/ /fraction/ /new value/" 
    echo ">>> where"
    echo ">>>   /file/       is the name of a netCDF file"
    echo ">>>   /variable/   is the name of the variable for which a value"
    echo ">>>                 or a range of values will be reset"
    echo ">>>   /type/       is the variable's type, one of:"
    echo ">>>                  i2 - integer,        2 bytes"
    echo ">>>                  i4 - integer,        4 bytes"
    echo ">>>                  r4 - floating point, 4 bytes"
    echo ">>>                  r8 - floating point, 8 bytes"

    echo ">>>   /old value/  is the existing value that will be replaced"
    echo ">>>   /fraction/   gives the interval that will be replaced by /new value/"
    echo ">>>                  when /old value/ > 0, /new value/ will replace"
    echo ">>>                   all values in the interval"
    echo ">>>                    (1-<fraction>)*<old value> to (1+<fraction>)*<old value>"
    echo ">>>                   (inclusive)"
    echo ">>>   /new value/  is the new value for /variable/"
    echo ""
    echo ">>> Script terminates."
    echo ""
    exit
fi


# Specify source code directory:
################################
dir="/home/faam/lib/netCDF/utilities"


# Read command line argumnts:
#############################

filename=$1
vrblname=$2
vrbltype=$3
oldvalue=$4
fraction=$5
newvalue=$6


# Require non-existing flag file:
#################################

test -r ok_flag && echo ">>> Flag file exists!"
test -r ok_flag && echo ">>> Script terminates prematurely."
test -r ok_flag && echo ""
test -r ok_flag && exit


# mf $dir/nc_var_dims.make

# Run "n_varc_dims":
####################

$dir/nc_var_dims $filename $vrblname
test -r ok_flag || echo ">>> Execution of 'nc_var_dims' failed."
test -r ok_flag || echo ">>> Script terminates."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag
chmod 0666 ./nc_var_dims.inc
/bin/mv ./nc_var_dims.inc $dir/


# (Re-)Compile "nc_reset_value":
################################

cd $dir/
test -r ./nc_reset_value && /bin/rm ./nc_reset_value
make -f ./nc_reset_value.make
chmod 0777 ./nc_reset_value
/bin/rm *.o
/bin/rm ./nc_var_dims.inc
test -r nc_reset_value || echo ">>> Compilation of 'nc_reset_value' failed!"
test -r nc_reset_value || echo ">>> Script terminates prematurely."
test -r nc_reset_value || echo ""
test -r nc_reset_value || exit


# Run "nc_reset_value":
#######################

cd -
$dir/nc_reset_value $filename $vrblname $vrbltype $oldvalue $fraction $newvalue
/bin/rm $dir/nc_reset_value
test -r ok_flag || echo ">>> Execution of 'nc_reset_value' failed!"
test -r ok_flag || echo ">>> Script terminates prematurely."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag

exit

